globals [
  num-days                 ;; number of simulation rounds
  actives                  ;; dyads engaging in sharing interactions each day
  meat-threshold           ;; minimum number of kilocalories for large-game
  current-inequality       ;; current level of income inequality among agents
]
breed [
  bests best               ;; top hunters (modeled after best Hadza producers)
]
breed [
  regs reg                 ;; regular hunters (modeled after median Hadza producers)
]
breed [
  poors poor               ;; poor hunters (modeled after poorest Hadza producers)
]
directed-link-breed [
  dyads dyad               ;; directed dyads of potential givers and receivers
]
turtles-own [
  acquisition              ;; calories acquired
  own-income               ;; calories kept from own acquisitions
  share-income             ;; calories received from others' acquisitions
  total-income             ;; total calories (own-income + share-income)
  meat-number              ;; number of primary transfers (large game)
  share-number             ;; number of further transfers (all foods)
  daily-acquisition        ;; daily memory of calories acquired
  daily-owned              ;; daily memory of calories kept from own acquisitions
  daily-income             ;; daily memory of total calories
  daily-meat               ;; daily memory of number of primary transfers (large game)
  daily-breadth            ;; daily memory of number of further transfers (all foods)
]
dyads-own [
  share-amount             ;; calories transferred from A to B
  mem-sharing              ;; daily memory of calories transferred from A to B
]

;;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  set num-days 3000
  set meat-threshold (m-amount-regs / m-chance-regs) * 100
  set-group
  ask turtles [
    set daily-acquisition []
    set daily-owned []
    set daily-income []
    set daily-meat []
    set daily-breadth []
  ]
  ask dyads [
    set mem-sharing []
  ]
  reset-ticks
end

;; the structure of the group is defined by its (a) size; (b) individual heterogeneity
to set-group
  let population (bests-number + regs-number + poors-number)
  create-turtles population [
    create-dyads-to other turtles
    set breed poors set color blue
  ]
  ask n-of bests-number turtles [set breed bests set color red]
  ask n-of regs-number turtles with [breed != bests] [set breed regs set color green]
  repeat 5 [layout-tutte (bests) dyads 12]
  ifelse count bests = 1 [layout-circle bests 0] [layout-circle bests 3]
end

;;;;;;;;;;;;;;;;;;;;;;;;
;;; Main Procedures  ;;;
;;;;;;;;;;;;;;;;;;;;;;;;

to go
  if ticks >= num-days [
    show-outcomes
    stop
  ]
  ask turtles [
    set own-income 0
    set share-income 0
    set total-income 0
    set acquisition 0
    set meat-number 0
    set share-number 0
  ]
  ask dyads [
    set share-amount 0
  ]
  forage
  share
  tick
end

;; Daily food acquisition is simulated for three hunter types and two food types.
;; Default parameter values refer to data on sucess rates and average returns of
;; married Hadza hunters. Parameters are allowed to vary +/- 50% of default value.
to forage

  ;;top hunters acquire meat and other foods at an average
  ;;rate of (0.02 * 792500 + 0.37 * 2700) = 16850 kcal/day
  ask bests [
    if random 100 < m-chance-bests [
      set own-income own-income + (m-amount-bests / m-chance-bests) * 100
    ]
    if random 100 < o-chance-bests [
      set own-income own-income + (o-amount-bests / o-chance-bests) * 100
    ]
  ]

  ;;regular hunters acquire meat and other foods at an average
  ;;rate of (0.02 * 50000 + 0.43 * 4000) = 2725 kcal/day
  ask regs [
    if random 100 < m-chance-regs [
      set own-income own-income + (m-amount-regs / m-chance-regs) * 100
    ]
    if random 100 < o-chance-regs [
      set own-income own-income + (o-amount-regs / o-chance-regs) * 100
    ]
  ]

  ;;poor hunters acquire other foods at an average
  ;;rate of (0.40 * 3375) = 1350 kcal/day
  ask poors [
    if random 100 < o-chance-poors [
      set own-income own-income + (o-amount-poors / o-chance-poors) * 100
    ]
  ]

  ask turtles [
    set total-income total-income + own-income
    set acquisition acquisition + total-income
    set daily-acquisition lput total-income daily-acquisition
  ]
  ifelse sum [total-income] of turtles > 0 [
    set current-inequality update-gini [total-income] of turtles
  ][
    set current-inequality 1
  ]
end

;; reports caloric surplus of a potential giver "j" relative to a potential receiver "i"
to-report surplus [i j]
  let difference [total-income] of j - [total-income] of i
  ifelse difference < 1 [
    report 0
  ][
    report difference
  ]
end

;; reports true if agent's total-income contributes to increase group-level inequality
to-report qualified? [the-turtle]
  let other-people [other turtles] of the-turtle
  let other-inequality (update-gini [total-income] of other-people)
  ifelse current-inequality > other-inequality [
    report true
  ][
    report false
  ]
end

;; applies sharing rule for primary large game meat distributions
to update-meat-sharing
  let meat-givers []
  ask turtles with [acquisition >= meat-threshold] [
    set meat-givers lput self meat-givers
  ]
  if not empty? meat-givers [
    foreach meat-givers [the-giver ->
      let meat-receivers []
      let their-income []
      foreach sort actives with [end2 = the-giver] [the-dyad ->
        ask the-dyad [
          if surplus end1 end2 > 0 and qualified? end1 [
            set meat-receivers lput end1 meat-receivers
            set their-income lput [total-income] of end1 their-income
          ]
        ]
      ]
      if not empty? meat-receivers [
        let common-income ([total-income] of the-giver + sum their-income) / (length meat-receivers + 1)
        foreach meat-receivers [the-receiver ->
          let donation (common-income - [total-income] of the-receiver)
          if donation > 0 [
            ask the-receiver [
              set share-income share-income + donation
              set total-income own-income + share-income
              ask out-dyad-to the-giver [
                set share-amount share-amount + donation
              ]
            ]
          ]
        ]
        ask the-giver [
          set meat-number meat-number + length meat-receivers
          let donation ([total-income] of self - common-income)
          set share-income share-income - donation
          if share-income < 0 [
            set own-income own-income + share-income
            set share-income 0
          ]
          set total-income own-income + share-income
        ]
      ]
    ]
    set current-inequality (update-gini [total-income] of turtles)
  ]
end

;; applies sharing rule for secondary food distributions
to update-other-sharing
  let donation (surplus end1 end2) / 2
  set share-amount share-amount + donation
  ask end1 [
    set share-income share-income + donation
    set total-income own-income + share-income
  ]
  ask end2 [
    set share-income share-income - donation
    if share-income < 0 [
      set share-number share-number + 1
      set own-income own-income + share-income
      set share-income 0
    ]
    set total-income own-income + share-income
  ]
  set current-inequality (update-gini [total-income] of turtles)
end

;; randomly selects which hunter dyads interact based on sharing rule and conformity level
to share
  set actives n-of round (conformity * count dyads) dyads
  update-meat-sharing
  let partner one-of actives with [surplus end1 end2 > 0 and qualified? end1]
  while [partner != nobody] [
    ask partner [
      update-other-sharing
    ]
    set partner one-of actives with [surplus end1 end2 > 0 and qualified? end1]
  ]
  ask turtles [
    set daily-meat lput meat-number daily-meat
    set daily-breadth lput share-number daily-breadth
    set daily-owned lput own-income daily-owned
    set daily-income lput total-income daily-income
  ]
  ask dyads [
    set mem-sharing lput share-amount mem-sharing
  ]
end

;;;;;;;;;;;;;;;;;
;;; Outcomes  ;;;
;;;;;;;;;;;;;;;;;

to show-outcomes
  equality
  depth
  breadth
end

to equality
  type "variance-reduction: " write precision (variance-reduction * 100) 2 print "%"
end

to depth
  type "top-depth: " type precision (top-depth * 100) 2
  type "%     reg-depth: " type precision (reg-depth * 100) 2
  type "%     poor-depth: " type precision (poor-depth * 100) 2 print "%"
  type "meat-depth: " type precision (meat-depth * 100) 2
  type "%     other-depth: " type precision (other-depth * 100) 2
  type "%     overall-depth: " type precision (overall-depth * 100) 2 print "%"
end

to breadth
  type "meat-breadth: " type precision (meat-breadth * 100) 2
  type "%     other-breadth: " type precision (other-breadth * 100) 2
  type "%     overall-breadth: " type precision (overall-breadth * 100) 2 print "%"
end

;; calculates gini-index for a list of income values
to-report update-gini [amount]
    let sorted-wealths sort amount
    let total-wealth sum sorted-wealths
    let wealth-sum-so-far 0
    let index 0
    let gini-index-reserve 0
    let lorenz-points []

    repeat length amount [
      set wealth-sum-so-far (wealth-sum-so-far + item index sorted-wealths)
      set lorenz-points lput ((wealth-sum-so-far / total-wealth) * 100) lorenz-points
      set index (index + 1)
      set gini-index-reserve
        gini-index-reserve +
        (index / length amount) -
        (wealth-sum-so-far / total-wealth)
    ]
      report precision ((gini-index-reserve / length amount) / 0.5) 2
end

;; reports income variance reduction after sharing
to-report variance-reduction
  let agents sort turtles
  let out-list []
  let index 0
  while [index < num-days][
    let in-list1 []
    let in-list2 []
    foreach agents [the-agent ->
      ask the-agent [
        set in-list1 lput item index [daily-income] of the-agent in-list1
        set in-list2 lput item index [daily-acquisition] of the-agent in-list2
      ]
    ]
    ifelse sum in-list2 > 0 [
      set out-list lput (standard-deviation in-list1 / standard-deviation in-list2) out-list
    ][
      set out-list lput 0 out-list
    ]
    set index index + 1
  ]
  report 1 - mean out-list
end

;; reports sharing depth for top hunters
to-report top-depth
  let agents sort turtles with [color = red]
  let the-list []
  foreach agents [the-agent ->
    ask the-agent [
      ifelse sum daily-acquisition > 0 [
        set the-list lput (1 - (round mean daily-owned / round mean daily-acquisition)) the-list
      ][
        set the-list lput 0 the-list
      ]
    ]
  ]
  report mean the-list
end

;; reports sharing depth for regular hunters
to-report reg-depth
  let agents sort turtles with [color = green]
  let the-list []
  foreach agents [the-agent ->
    ask the-agent [
      ifelse sum daily-acquisition > 0 [
        set the-list lput (1 - (round mean daily-owned / round mean daily-acquisition)) the-list
      ][
        set the-list lput 0 the-list
      ]
    ]
  ]
  report mean the-list
end

;; reports sharing depth for poor hunters
to-report poor-depth
  let agents sort turtles with [color = blue]
  let the-list []
  foreach agents [the-agent ->
    ask the-agent [
      ifelse sum daily-acquisition > 0 [
        set the-list lput (1 - (round mean daily-owned / round mean daily-acquisition)) the-list
      ][
        set the-list lput 0 the-list
      ]
    ]
  ]
  report mean the-list
end

;; reports sharing depth of large game
to-report meat-depth
  let agents sort turtles
  let the-list1 []
  let the-list2 []
  foreach agents [the-agent ->
    let index 0
    while [index < length [daily-acquisition] of the-agent] [
      if item index [daily-acquisition] of the-agent >= meat-threshold [
        ask the-agent [
          set the-list1 lput item index daily-owned the-list1
          set the-list2 lput item index daily-acquisition the-list2
        ]
      ]
      set index index + 1
    ]
  ]
  ifelse sum the-list2 > 0 [
    report 1 - (sum the-list1 / sum the-list2)
  ][
    report 0
  ]
end

;; reports sharing depth of other foods
to-report other-depth
  let agents sort turtles
  let the-list1 []
  let the-list2 []
  foreach agents [the-agent ->
    let index 0
    while [index < length [daily-acquisition] of the-agent] [
      if item index [daily-acquisition] of the-agent > 0 and item index [daily-acquisition] of the-agent < meat-threshold [
        ask the-agent [
          set the-list1 lput item index daily-owned the-list1
          set the-list2 lput item index daily-acquisition the-list2
        ]
      ]
      set index index + 1
    ]
  ]
  ifelse sum the-list2 > 0 [
    report 1 - (sum the-list1 / sum the-list2)
  ][
    report 0
  ]
end

;; reports sharing depth of all foods
to-report overall-depth
  let agents sort turtles
  let the-list1 []
  let the-list2 []
  foreach agents [the-agent ->
    let index 0
    while [index < length [daily-acquisition] of the-agent] [
      if item index [daily-acquisition] of the-agent > 0 [
        ask the-agent [
          set the-list1 lput item index daily-owned the-list1
          set the-list2 lput item index daily-acquisition the-list2
        ]
      ]
      set index index + 1
    ]
  ]
  ifelse sum the-list2 > 0 [
    report 1 - (sum the-list1 / sum the-list2)
  ][
    report 0
  ]
end

;; reports sharing breadth of large game
to-report meat-breadth
  let agents sort turtles
  let the-list []
  foreach agents [the-agent ->
    let index 0
    while [index < length [daily-acquisition] of the-agent] [
      if item index [daily-acquisition] of the-agent >= meat-threshold [
        ask the-agent [
          set the-list lput (item index daily-meat) the-list
        ]
      ]
      set index index + 1
    ]
  ]
  ifelse not empty? the-list [
    report (mean the-list) / (count turtles - 1)
  ][
    report 0
  ]
end

;; reports sharing breadth of other foods
to-report other-breadth
  let agents sort turtles
  let the-list []
  foreach agents [the-agent ->
    let index 0
    while [index < length [daily-acquisition] of the-agent] [
      if item index [daily-acquisition] of the-agent > 0 and item index [daily-acquisition] of the-agent < meat-threshold [
        ask the-agent [
          set the-list lput (item index daily-breadth) the-list
        ]
      ]
      set index index + 1
    ]
  ]
  ifelse not empty? the-list [
    report (mean the-list) / (count turtles - 1)
  ][
    report 0
  ]
end

;; reports sharing breadth of all foods
to-report overall-breadth
  let agents sort turtles
  let the-list []
  foreach agents [the-agent ->
    let index 0
    while [index < length [daily-acquisition] of the-agent] [
      if item index [daily-acquisition] of the-agent > 0 [
        ask the-agent [
          set the-list lput (item index daily-meat + item index daily-breadth) the-list
        ]
      ]
      set index index + 1
    ]
  ]
  ifelse not empty? the-list [
    report (mean the-list) / (count turtles - 1)
  ][
    report 0
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
647
448
-1
-1
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
29
25
95
58
NIL
setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
112
25
175
58
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

PLOT
662
14
979
238
Mean Acquisition Over Time
days
mean acquisition (kcal)
0.0
10.0
0.0
10.0
true
false
"set-plot-x-range 0 num-days" ""
PENS
"bests" 1.0 0 -2674135 true "" "plot mean [mean daily-acquisition] of bests"
"regs" 1.0 0 -10899396 true "" "plot mean [mean daily-acquisition] of regs"
"poors" 1.0 0 -13345367 true "" "plot mean [mean daily-acquisition] of poors"

PLOT
663
261
981
466
Mean Income Over Time
days
mean balance (kcal)
0.0
10.0
0.0
10.0
true
false
"set-plot-x-range 0 num-days" ""
PENS
"bests" 1.0 0 -2674135 true "" "plot mean [mean daily-income] of bests"
"regs" 1.0 0 -10899396 true "" "plot mean [mean daily-income] of regs"
"poors" 1.0 0 -13345367 true "" "plot mean [mean daily-income] of poors"

PLOT
1001
14
1305
239
Household Consumption
all others                     producers
consumed %
0.0
2.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "let agents sort turtles\nlet mean-proportion []\nlet mean-others []\nforeach agents [the-agent ->\n  ask the-agent [\n    set mean-proportion lput\n    (round mean daily-owned / round mean daily-acquisition) mean-proportion\n    set mean-others lput\n    ((1 - (round mean daily-owned / round mean daily-acquisition))  / (count turtles - 1))\n    mean-others\n  ]\n]\nplot-pen-reset\nset-plot-pen-color grey\nplot (mean mean-others) * 100\nset-plot-pen-color black\nplot (mean mean-proportion) * 100"

PLOT
1002
263
1307
467
Sharing Breadth
group
receiving others
0.0
3.0
0.0
10.0
true
false
"set-plot-y-range 0 (count turtles - 1)" ""
PENS
"default" 1.0 1 -16777216 true "" "plot-pen-reset\nset-plot-pen-color red\nplot mean [mean daily-breadth] of bests\nset-plot-pen-color green\nplot mean [mean daily-breadth] of regs\nset-plot-pen-color blue\nplot mean [mean daily-breadth] of poors"

SLIDER
29
61
62
172
conformity
conformity
0
1
0.78
0.01
1
NIL
VERTICAL

SLIDER
72
62
105
172
bests-number
bests-number
1
10
1.0
1
1
NIL
VERTICAL

SLIDER
117
63
150
172
regs-number
regs-number
1
10
3.0
1
1
NIL
VERTICAL

SLIDER
162
63
195
172
poors-number
poors-number
1
10
3.0
1
1
NIL
VERTICAL

SLIDER
30
177
202
210
m-chance-bests
m-chance-bests
1
3
2.0
0.2
1
%
HORIZONTAL

SLIDER
30
214
202
247
m-amount-bests
m-amount-bests
7900
23700
15800.0
100
1
kcal
HORIZONTAL

SLIDER
30
251
202
284
o-chance-bests
o-chance-bests
18
55
37.0
1
1
%
HORIZONTAL

SLIDER
30
288
203
321
o-amount-bests
o-amount-bests
500
1500
1000.0
100
1
kcal
HORIZONTAL

SLIDER
30
325
203
358
m-chance-regs
m-chance-regs
1
3
2.0
0.2
1
%
HORIZONTAL

SLIDER
30
362
203
395
m-amount-regs
m-amount-regs
500
1500
1000.0
100
1
kcal
HORIZONTAL

SLIDER
31
399
203
432
o-chance-regs
o-chance-regs
21
64
43.0
1
1
%
HORIZONTAL

SLIDER
31
435
203
468
o-amount-regs
o-amount-regs
850
2550
1700.0
50
1
kcal
HORIZONTAL

SLIDER
229
453
401
486
o-chance-poors
o-chance-poors
20
60
40.0
1
1
%
HORIZONTAL

SLIDER
414
453
601
486
o-amount-poors
o-amount-poors
675
2025
1350.0
75
1
kcal
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="acquisition" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>round mean [mean daily-acquisition] of bests</metric>
    <metric>round mean [mean daily-acquisition] of regs</metric>
    <metric>round mean [mean daily-acquisition] of poors</metric>
    <enumeratedValueSet variable="prob-middle-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-far-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="large-net?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="small-network" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[breed] of turtle 0</metric>
    <metric>[breed] of turtle 1</metric>
    <metric>[breed] of turtle 2</metric>
    <metric>[breed] of turtle 3</metric>
    <metric>[breed] of turtle 4</metric>
    <metric>[breed] of turtle 5</metric>
    <metric>[breed] of turtle 6</metric>
    <metric>[round acquisition] of turtle 0</metric>
    <metric>[round acquisition] of turtle 1</metric>
    <metric>[round acquisition] of turtle 2</metric>
    <metric>[round acquisition] of turtle 3</metric>
    <metric>[round acquisition] of turtle 4</metric>
    <metric>[round acquisition] of turtle 5</metric>
    <metric>[round acquisition] of turtle 6</metric>
    <metric>[round total-income] of turtle 0</metric>
    <metric>[round total-income] of turtle 1</metric>
    <metric>[round total-income] of turtle 2</metric>
    <metric>[round total-income] of turtle 3</metric>
    <metric>[round total-income] of turtle 4</metric>
    <metric>[round total-income] of turtle 5</metric>
    <metric>[round total-income] of turtle 6</metric>
    <metric>[round own-income] of turtle 0</metric>
    <metric>[round own-income] of turtle 1</metric>
    <metric>[round own-income] of turtle 2</metric>
    <metric>[round own-income] of turtle 3</metric>
    <metric>[round own-income] of turtle 4</metric>
    <metric>[round own-income] of turtle 5</metric>
    <metric>[round own-income] of turtle 6</metric>
    <metric>[share-number] of turtle 0</metric>
    <metric>[share-number] of turtle 1</metric>
    <metric>[share-number] of turtle 2</metric>
    <metric>[share-number] of turtle 3</metric>
    <metric>[share-number] of turtle 4</metric>
    <metric>[share-number] of turtle 5</metric>
    <metric>[share-number] of turtle 6</metric>
    <enumeratedValueSet variable="prob-middle-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-far-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="large-net?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="large-network" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[breed] of turtle 0</metric>
    <metric>[breed] of turtle 1</metric>
    <metric>[breed] of turtle 2</metric>
    <metric>[breed] of turtle 3</metric>
    <metric>[breed] of turtle 4</metric>
    <metric>[breed] of turtle 5</metric>
    <metric>[breed] of turtle 6</metric>
    <metric>[breed] of turtle 7</metric>
    <metric>[breed] of turtle 8</metric>
    <metric>[breed] of turtle 9</metric>
    <metric>[breed] of turtle 10</metric>
    <metric>[breed] of turtle 11</metric>
    <metric>[breed] of turtle 12</metric>
    <metric>[round acquisition] of turtle 0</metric>
    <metric>[round acquisition] of turtle 1</metric>
    <metric>[round acquisition] of turtle 2</metric>
    <metric>[round acquisition] of turtle 3</metric>
    <metric>[round acquisition] of turtle 4</metric>
    <metric>[round acquisition] of turtle 5</metric>
    <metric>[round acquisition] of turtle 6</metric>
    <metric>[round acquisition] of turtle 7</metric>
    <metric>[round acquisition] of turtle 8</metric>
    <metric>[round acquisition] of turtle 9</metric>
    <metric>[round acquisition] of turtle 10</metric>
    <metric>[round acquisition] of turtle 11</metric>
    <metric>[round acquisition] of turtle 12</metric>
    <metric>[round total-income] of turtle 0</metric>
    <metric>[round total-income] of turtle 1</metric>
    <metric>[round total-income] of turtle 2</metric>
    <metric>[round total-income] of turtle 3</metric>
    <metric>[round total-income] of turtle 4</metric>
    <metric>[round total-income] of turtle 5</metric>
    <metric>[round total-income] of turtle 6</metric>
    <metric>[round total-income] of turtle 7</metric>
    <metric>[round total-income] of turtle 8</metric>
    <metric>[round total-income] of turtle 9</metric>
    <metric>[round total-income] of turtle 10</metric>
    <metric>[round total-income] of turtle 11</metric>
    <metric>[round total-income] of turtle 12</metric>
    <metric>[round own-income] of turtle 0</metric>
    <metric>[round own-income] of turtle 1</metric>
    <metric>[round own-income] of turtle 2</metric>
    <metric>[round own-income] of turtle 3</metric>
    <metric>[round own-income] of turtle 4</metric>
    <metric>[round own-income] of turtle 5</metric>
    <metric>[round own-income] of turtle 6</metric>
    <metric>[round own-income] of turtle 7</metric>
    <metric>[round own-income] of turtle 8</metric>
    <metric>[round own-income] of turtle 9</metric>
    <metric>[round own-income] of turtle 10</metric>
    <metric>[round own-income] of turtle 11</metric>
    <metric>[round own-income] of turtle 12</metric>
    <metric>[share-number] of turtle 0</metric>
    <metric>[share-number] of turtle 1</metric>
    <metric>[share-number] of turtle 2</metric>
    <metric>[share-number] of turtle 3</metric>
    <metric>[share-number] of turtle 4</metric>
    <metric>[share-number] of turtle 5</metric>
    <metric>[share-number] of turtle 6</metric>
    <metric>[share-number] of turtle 7</metric>
    <metric>[share-number] of turtle 8</metric>
    <metric>[share-number] of turtle 9</metric>
    <metric>[share-number] of turtle 10</metric>
    <metric>[share-number] of turtle 11</metric>
    <metric>[share-number] of turtle 12</metric>
    <enumeratedValueSet variable="prob-middle-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-far-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="large-net?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="result-sharing" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>1 - (mean [mean daily-owned] of bests / mean [mean daily-acquisition] of bests)</metric>
    <metric>1 - (mean [mean daily-owned] of regs / mean [mean daily-acquisition] of regs)</metric>
    <metric>1 - (mean [mean daily-owned] of poors / mean [mean daily-acquisition] of poors)</metric>
    <enumeratedValueSet variable="prob-middle-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-far-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="large-net?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <steppedValueSet variable="share-factor" first="0" step="5" last="50"/>
  </experiment>
  <experiment name="small-overall" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean [mean daily-owned / mean daily-acquisition] of turtles</metric>
    <metric>(1 - mean [mean daily-owned / mean daily-acquisition] of turtles) / (count turtles - 1)</metric>
    <metric>mean [mean daily-breadth] of turtles</metric>
    <metric>reduction</metric>
    <steppedValueSet variable="prob-middle-interaction" first="0" step="50" last="100"/>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-far-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="large-net?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <steppedValueSet variable="share-factor" first="0" step="5" last="50"/>
  </experiment>
  <experiment name="large-overall" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean [mean daily-owned / mean daily-acquisition] of turtles</metric>
    <metric>(1 - mean [mean daily-owned / mean daily-acquisition] of turtles) / (count turtles - 1)</metric>
    <metric>mean [mean daily-breadth] of turtles</metric>
    <metric>reduction</metric>
    <steppedValueSet variable="prob-middle-interaction" first="0" step="50" last="100"/>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <steppedValueSet variable="prob-far-interaction" first="0" step="50" last="100"/>
    <enumeratedValueSet variable="large-net?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <steppedValueSet variable="share-factor" first="0" step="5" last="50"/>
  </experiment>
  <experiment name="large-cormat" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>csv:to-row item 0 cormat</metric>
    <metric>csv:to-row item 1 cormat</metric>
    <metric>csv:to-row item 2 cormat</metric>
    <metric>csv:to-row item 3 cormat</metric>
    <metric>csv:to-row item 4 cormat</metric>
    <metric>csv:to-row item 5 cormat</metric>
    <metric>csv:to-row item 6 cormat</metric>
    <metric>csv:to-row item 7 cormat</metric>
    <metric>csv:to-row item 8 cormat</metric>
    <metric>csv:to-row item 9 cormat</metric>
    <metric>csv:to-row item 10 cormat</metric>
    <metric>csv:to-row item 11 cormat</metric>
    <metric>csv:to-row item 12 cormat</metric>
    <steppedValueSet variable="prob-middle-interaction" first="0" step="50" last="100"/>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <steppedValueSet variable="prob-far-interaction" first="0" step="50" last="100"/>
    <enumeratedValueSet variable="large-net?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <steppedValueSet variable="share-factor" first="10" step="10" last="50"/>
  </experiment>
  <experiment name="small-cormat" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>csv:to-row item 0 cormat</metric>
    <metric>csv:to-row item 1 cormat</metric>
    <metric>csv:to-row item 2 cormat</metric>
    <metric>csv:to-row item 3 cormat</metric>
    <metric>csv:to-row item 4 cormat</metric>
    <metric>csv:to-row item 5 cormat</metric>
    <metric>csv:to-row item 6 cormat</metric>
    <steppedValueSet variable="prob-middle-interaction" first="0" step="50" last="100"/>
    <enumeratedValueSet variable="num-days">
      <value value="6000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-far-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="large-net?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-close-interaction">
      <value value="100"/>
    </enumeratedValueSet>
    <steppedValueSet variable="share-factor" first="10" step="10" last="50"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
